summaryrefslogtreecommitdiffstats
path: root/cmd
diff options
context:
space:
mode:
Diffstat (limited to 'cmd')
-rw-r--r--cmd/hook.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/cmd/hook.go b/cmd/hook.go
index 312c9a14fc..2fbbfb4d21 100644
--- a/cmd/hook.go
+++ b/cmd/hook.go
@@ -221,8 +221,8 @@ Gitea or set your environment appropriately.`, "")
total++
lastline++
- // If the ref is a branch, check if it's protected
- if strings.HasPrefix(refFullName, git.BranchPrefix) {
+ // If the ref is a branch or tag, check if it's protected
+ if strings.HasPrefix(refFullName, git.BranchPrefix) || strings.HasPrefix(refFullName, git.TagPrefix) {
oldCommitIDs[count] = oldCommitID
newCommitIDs[count] = newCommitID
refFullNames[count] = refFullName
@@ -230,7 +230,7 @@ Gitea or set your environment appropriately.`, "")
fmt.Fprintf(out, "*")
if count >= hookBatchSize {
- fmt.Fprintf(out, " Checking %d branches\n", count)
+ fmt.Fprintf(out, " Checking %d references\n", count)
hookOptions.OldCommitIDs = oldCommitIDs
hookOptions.NewCommitIDs = newCommitIDs
@@ -261,7 +261,7 @@ Gitea or set your environment appropriately.`, "")
hookOptions.NewCommitIDs = newCommitIDs[:count]
hookOptions.RefFullNames = refFullNames[:count]
- fmt.Fprintf(out, " Checking %d branches\n", count)
+ fmt.Fprintf(out, " Checking %d references\n", count)
statusCode, msg := private.HookPreReceive(username, reponame, hookOptions)
switch statusCode {